package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.36.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.36.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@("`0`````````````#`!8````!````````(B@`````````0```````
M`+&(``````!``#@`"0!``!H`&0````8````$`````````$``````````0```
M``````!``````````?@````````!^``````````(`````P````0````````"
M.`````````(X`````````C@`````````#P`````````/``````````$````!
M````!0```````````````````````````````````````*-P````````HW``
M```````0``````$````&````````J\@```````"[R````````+O(````````
M!+@````````$X````````!```````@````8```````"KV````````+O8````
M````N]@````````"``````````(```````````@````$````!`````````)(
M`````````D@````````"2`````````!$`````````$0`````````!&1TY5``
M```$````````G-````````"<T````````)S0`````````-P`````````W```
M```````$9'3E40````8`````````````````````````````````````````
M`````````````````````!!D=.52````!````````*O(````````N\@`````
M``"[R`````````0X````````!#@``````````2]L:6(O;&0V-"YS;RXQ````
M```$````%`````-'3E4`R"GYR'1,%%"8$=KAX>RK,CDR1:H````$````$```
M``%'3E4```````````,````"```````````````1````0P````0````(A`1`
M!0`0$""$`(:`!``"*`@$(`D```F""`(`ND$0@(@`````````0P```$8```!)
M````2@```%$```!2````4P````````!5````5@```%<```!8````60```%L`
M`````````!_?Q6XM1][.?)I_:[:;Q2Y\U&34#N3_(1Q8<=D!QD?B;XL!LL#C
M2ZR'U_I"+#_EPGR2X[I@;*'[UD,):V;,KV?LU45"TW`'B>W;8C/,)8P5"Y<Z
M#9N<J7\*`J?@4)X::TG[X*,`````````````````````````````````````
M`P``"P```````!C(``````````````-?$@``````````````````````````
M``#D$@````````````````````````````*K$0``````````````````````
M``````)[$@````````````````````````````"6$@``````````````````
M``````````%=$@````````````````````````````&U$@``````````````
M``````````````#Z$@````````````````````````````)M$@``````````
M``````````````````'N$@`````````````````````````````!(```````
M``````````````````````%T$@````````````````````````````*S$@``
M``````````````````````````&<$@````````````````````````````'C
M$@````````````````````````````$K$@``````````````````````````
M``'<$@````````````````````````````$;$@``````````````````````
M``````$-$@````````````````````````````'4$@``````````````````
M``````````*A$@`````````````````````````````0(```````````````
M``````````````%[$@````````````````````````````("$@``````````
M``````````````````*I$0````````````````````````````)0$@``````
M```````````````````````L(`````````````````````````````(P$@``
M``````````````````````````!&$@````````````````````````````(+
M$@````````````````````````````!C%@``````````````````````````
M``%-$@````````````````````````````&N$@``````````````````````
M``````!V$@````````````````````````````#3$@``````````````````
M``````````"'$@````````````````````````````&D$@``````````````
M``````````````)7(@````````````````````````````*0$@``````````
M``````````````````&7$@````````````````````````````"W$@``````
M``````````````````````'U$@````````````````````````````'[$@``
M``````````````````````````$_$@````````````````````````````#N
M$@````````````````````````````&&$@``````````````````````````
M``)F$@````````````````````````````(A$@``````````````````````
M``````(O$@````````````````````````````'-$@``````````````````
M``````````"B$@````````````````````````````'I$@``````````````
M``````````````%H$@````````````````````````````#I$@``````````
M``````````````````&^$@````````````````````````````#&$0``````
M``````````````````````'%$@````````````````````````````*"$@``
M``````````````````````````(3$@````````````````````````````$T
M$@````````````````````````````)S$@``````````````````````````
M``!4$@````````````````````````````(W$@``````````````````````
M``````*)$@````````````````````````````))$0``````````````````
M``````````-H$@``#0```````$`H`````````1````.]$@``#0```````#8X
M````````!Z0```)$$@``#0```````!_H`````````CP```+?$@``#0``````
M`"L0``````````8```+]$@``#0```````#W@`````````D0```/C$@``#0``
M`````"L8`````````B0```.C$```%P```````,"```````````````+P$@``
M#0```````"U``````````#8```,3$@``#0```````#1H`````````)````-T
M$0``#P```````%OH``````````0```.0$@``#0```````%DH`````````3@`
M``.;$@``#0```````"H``````````#@```.X$```%P```````,"H````````
M``````/1$@``#0```````#4H`````````0H```.#$```%@```````,``````
M``````````,W$@``#0```````"UX`````````0P```/*$```%@```````,"`
M``````````````/P$0``%@```````,!X``````````@```.)$@``#0``````
M`"(H``````````````.O$@``#0```````%BX`````````&P```.%(```%@``
M`````,````````````````--$@``#0```````#3X`````````"X```,A$@``
M#0```````"HX`````````-0```-#$@``#0```````%I@`````````48```/Z
M$@``#0```````"Z(````````!=P`7U]G;6]N7W-T87)T7U\`7TE435]D97)E
M9VES=&5R5$U#;&]N951A8FQE`%])5$U?<F5G:7-T97)434-L;VYE5&%B;&4`
M4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!03%]C=7)R96YT7V-O;G1E
M>'0`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!097)L7V=E=%]S
M=@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7W-V7W-E='!V;@!03%]D;U]U
M;F1U;7``4&5R;%]N97=84U]F;&%G<P!P97)L7V9R964`4&5R;%]M9U]S970`
M4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C
M:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!B;V]T7T1Y
M;F%,;V%D97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]A
M;&QO8P!?7W-T86-K7V-H:U]F86EL`&5X:70`;'-E96LV-`!R96%D9&ER-C0`
M<W1R9'5P`&-L;W-E9&ER`&]P96XV-`!S=')R8VAR`'5N;&EN:P!M96UM;W9E
M`'-T<G1O:P!R;61I<@!R96%D`'-T<G-T<@!M:V1I<@!G971P:60`<F5A9&QI
M;FL`<F5A;&QO8P!?7W-P<FEN=&9?8VAK`%]?9G!R:6YT9E]C:&L`;'-T870V
M-`!?7VQI8F-?<W1A<G1?;6%I;@!S=&1E<G(`;65M8VAR`%]?8WAA7V9I;F%L
M:7IE`'-T<F-H<@!C;&]S90!O<&5N9&ER`&=E='5I9`!A8V-E<W,`;65M8W!Y
M`%]?97)R;F]?;&]C871I;VX`<W1R;F-M<`!?7V5N=FER;VX`7U]R96=I<W1E
M<E]A=&9O<FL`;&EB<&5R;"YS;RXU+C,V`&QI8F,N<V\N-@!P87)?8W5R<F5N
M=%]E>&5C`'!A<E]B87-E;F%M90!84U]);G1E<FYA;'-?4$%27T)/3U0`<&%R
M7V5N=E]C;&5A;@!P87)?8W5R<F5N=%]E>&5C7W!R;V,`<&%R7V1I<FYA;64`
M<VAA7V9I;F%L`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A
M;G5P`%])3U]S=&1I;E]U<V5D`%]?9&%T85]S=&%R=`!S:&%?=7!D871E`'AS
M7VEN:70`7U]B<W-?<W1A<G0`<VAA7VEN:70`7V5N9`!P87)?;6MT;7!D:7(`
M7V5D871A`'!A<E]S971U<%]L:6)P871H`'!A<E]F:6YD<')O9P!M>5]P87)?
M<&P`<&%R7VEN:71?96YV`$=,24)#7S(N,S0`1TQ)0D-?,BXT`$=,24)#7S(N
M,S,`1TQ)0D-?,BXS+C(`1TQ)0D-?,BXR``````````(``0`"``(``0`!``(`
M`0`"``(``0`"``,``@`"``$``@`!``$``@`"``$``0`"``(``@`!``0``0`"
M``$``0`"``$``0`!``(``@`"``(``0`"``(``0`!``4``@`%``0``@`!``(`
M`0`"``(``0`"``(`!0`!``(``0`&``(``@`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!`````0`%```"U0```!``
M````!I:1M`````8```0'````$`UI:10````%```$$@```!`&EI&S````!```
M!!P````0"6D9<@````,```0G````$`UI:1(````"```$,P````````````"[
MR``````````,````````(Q@```````"[T``````````,````````(M``````
M``"_^``````````,````````'^@```````#`"``````````,````````P`@`
M``````#`&``````````,````````7L(```````#`(``````````,````````
M7$0```````#`,``````````,````````7.0```````#`.``````````,````
M````7.@```````#`0``````````,````````7K8```````#`2``````````,
M````````7$H```````#`4``````````,````````7KX```````#`8```````
M```,````````7J8```````#`:``````````,````````7JP```````#`>```
M```````,````````7L@```````"_H`````0````*``````````````````"_
MJ`````D````*``````````````````"_L`````P````*````````````````
M``"_N````!<````*``````````````````"_P````!P````*````````````
M``````"_R````"`````X``````````````````"_T````"$````*````````
M``````````"_V````",````*``````````````````"_X````"<````*````
M``````````````"_Z````#D````*``````````````````"_\````$(````*
M``````````````````"]\`````(````+``````````````````"]^`````,`
M```+``````````````````"^``````4````+``````````````````"^"```
M``8````+``````````````````"^$`````<````+``````````````````"^
M&`````@````+``````````````````"^(`````H````+````````````````
M``"^*`````L````+``````````````````"^,`````T````+````````````
M``````"^.`````X````+``````````````````"^0`````\````+````````
M``````````"^2````!`````+``````````````````"^4````!$````+````
M``````````````"^6````!(````+``````````````````"^8````!,````+
M``````````````````"^:````!0````+``````````````````"^<````!4`
M```+``````````````````"^>````!8````+``````````````````"^@```
M`!@````+``````````````````"^B````!D````+``````````````````"^
MD````!L````+``````````````````"^F````!T````+````````````````
M``"^H````!X````+``````````````````"^J````!\````+````````````
M``````"^L````"(````+``````````````````"^N````"0````+````````
M``````````"^P````"4````+``````````````````"^R````"8````+````
M``````````````"^T````"<````+``````````````````"^V````"@````+
M``````````````````"^X````"D````+``````````````````"^Z````"H`
M```+``````````````````"^\````"L````+``````````````````"^^```
M`"P````+``````````````````"_`````"T````+``````````````````"_
M"````"X````+``````````````````"_$````"\````+````````````````
M``"_&````#`````+``````````````````"_(````#$````+````````````
M``````"_*````#(````+``````````````````"_,````#,````+````````
M``````````"_.````#0````+``````````````````"_0````#4````+````
M``````````````"_2````#8````+``````````````````"_4````#<````+
M``````````````````"_6````#@````+``````````````````"_8````#H`
M```+``````````````````"_:````#L````+``````````````````"_<```
M`#P````+``````````````````"_>````#T````+``````````````````"_
M@````#X````+``````````````````"_B````#\````+````````````````
M``"_D````$`````+``````````````````"_F````$$````+``````````#K
M;_`P`"2Y!``?I_O_8.,0\```),#```!2?L`0``!39^,0$```!+D"`!&GA``#
M#>'C0/$0``3K;_#0``0']`<'XQ#P.``DP!```%)ET@?P,!`(XQ`0$``$!_$'
M``<`!P#`$```4F3C$!````0'\0T0XQ`0#``4P/3____E`````,`0``!26.,0
M$```!`?Q#1#C$!`,`!3`]/___]4````8P!```%),XQ`0```$!_$-$.,0$`P`
M%,#T____Q0```##`$```4D#C$!````0'\0T0XQ`0#``4P/3___^U````2,`0
M``!2-.,0$```!`?Q#1#C$!`,`!3`]/___Z4```!@P!```%(HXQ`0```$!_$-
M$.,0$`P`%,#T____E0```'C`$```4ASC$!````0'\0T0XQ`0#``4P/3___^%
M````D,`0``!2$.,0$```!`?Q#1#C$!`,`!3`]/___W4```"HP!```%($XQ`0
M```$!_$-$.,0$`P`%,#T____90```,#`$```4?CC$!````0'\0T0XQ`0#``4
MP/3___]5````V,`0``!1[.,0$```!`?Q#1#C$!`,`!3`]/___T4```#PP!``
M`%'@XQ`0```$!_$-$.,0$`P`%,#T____-0```0C`$```4=3C$!````0'\0T0
MXQ`0#``4P/3___\E```!(,`0``!1R.,0$```!`?Q#1#C$!`,`!3`]/___Q4`
M``$XP!```%&\XQ`0```$!_$-$.,0$`P`%,#T____!0```5#`$```4;#C$!``
M``0'\0T0XQ`0#``4P/3___[U```!:,`0``!1I.,0$```!`?Q#1#C$!`,`!3`
M]/___N4```&`P!```%&8XQ`0```$!_$-$.,0$`P`%,#T___^U0```9C`$```
M48SC$!````0'\0T0XQ`0#``4P/3___[%```!L,`0``!1@.,0$```!`?Q#1#C
M$!`,`!3`]/___K4```'(P!```%%TXQ`0```$!_$-$.,0$`P`%,#T___^I0``
M`>#`$```46CC$!````0'\0T0XQ`0#``4P/3___Z5```!^,`0``!17.,0$```
M!`?Q#1#C$!`,`!3`]/___H4```(0P!```%%0XQ`0```$!_$-$.,0$`P`%,#T
M___^=0```BC`$```443C$!````0'\0T0XQ`0#``4P/3___YE```"0,`0``!1
M..,0$```!`?Q#1#C$!`,`!3`]/___E4```)8P!```%$LXQ`0```$!_$-$.,0
M$`P`%,#T___^10```G#`$```42#C$!````0'\0T0XQ`0#``4P/3___XU```"
MB,`0``!1%.,0$```!`?Q#1#C$!`,`!3`]/___B4```*@P!```%$(XQ`0```$
M!_$-$.,0$`P`%,#T___^%0```KC`$```4/SC$!````0'\0T0XQ`0#``4P/3_
M__X%```"T,`0``!0\.,0$```!`?Q#1#C$!`,`!3`]/___?4```+HP!```%#D
MXQ`0```$!_$-$.,0$`P`%,#T___]Y0```P#`$```4-CC$!````0'\0T0XQ`0
M#``4P/3___W5```#&,`0``!0S.,0$```!`?Q#1#C$!`,`!3`]/___<4```,P
MP!```%#`XQ`0```$!_$-$.,0$`P`%,#T___]M0```TC`$```4+3C$!````0'
M\0T0XQ`0#``4P/3___VE```#8,`0``!0J.,0$```!`?Q#1#C$!`,`!3`]/__
M_94```-XP!```%"<XQ`0```$!_$-$.,0$`P`%,#T___]A0```Y#`$```4)#C
M$!````0'\0T0XQ`0#``4P/3___UU```#J,`0``!0A.,0$```!`?Q#1#C$!`,
M`!3`]/___64```/`P!```%!XXQ`0```$!_$-$.,0$`P`%,#T___]50```]C`
M$```4&SC$!````0'\0T0XQ`0#``4P/3___U%```#\,`0``!08.,0$```!`?Q
M#1#C$!`,`!3`]/___34```0(P!```%!4XQ`0```$!_$-$.,0$`P`%,#T___]
M)0``!"#`$```4$CC$!````0'\0T0XQ`0#``4P/3___T5```$.,`0``!0/.,0
M$```!`?Q#1#C$!`,`!3`]/___04```10P!```%`PXQ`0```$!_$-$.,0$`P`
M%,#T___\]0``!&C`$```4"3C$!````0'\0T0XQ`0#``4P/3___SE```$@,`0
M``!0&.,0$```!`?Q#1#C$!`,`!3`]/___-4```28P!```%`,XQ`0```$!_$-
M$.,0$`P`%,#T___\Q0``!+#`$```4`#C$!````0'\0T0XQ`0#``4P/3___RU
M```$R,`0``!/].,0$```!`?Q#1#C$!`,`!3`]/___*4```3@P!```$_HXQ`0
M```$!_$-$.,0$`P`%,#T___\E0``!/CK;_`P`"3C\/\X_W'C,/"H`"3C0/"@
M`"10(/"T04#PH$$P\*A!(/"TLD\`L.N[`"``#;)/`+'2!_#`L"C`Y?___[+$
M2```3[_$*```3]2Y!``TP.4``!VWQ!@``$_4E0`0`*>$`*#`$```3[WC$!``
M``3C$;````18H/"TE@,4>NPJ``0`V+D4`"+K(@`#``VGJ@`#P.7___\&XS#P
MJ``$XQ`P```$XQ`@```DP!```!\%XQ`@"``DQ"L``$_XQ!@``$_IXQ`@$``D
MN00`4L`0```>]N,0(!@`)%@@\+2G+@`!I\0`H4$P,`BG"``$[$+__P#8N10`
M$..0,```!.L1``,`#>.14```)*<*``&G.P`(IT;_\>P2``,`V+D4`!'K$0`#
M``U!$5``N10`2N5($````*=I``#`,```!#3$*```3[W`Y?___#X8HA(BIX0`
M1,0H``!/LT&0\+S`Y?___A+`(```'::Y!``YP.4```#FN0(`(J>$`#G$*```
M3Y_`Y?__^_#`Y?___3VY%``JU0?PP+`HIW0`4.MO\/@`!`?^P.7___SOQ"L`
M`$^(N0(`(J>$`#W`Y?___67`$```3Q+C(!````3C(K````22`"HGI_3_3<0H
M``!/<<#E___\<ABBI_3_M\`0``!/9.,@$````J>$``?`Y0``#R2G]/^^N00`
M.<`@```=+,#E````EL0K``!/3[D"`"*GA/^OI_3_[*<8``2G]/]ZIRD``<#E
M___]:,#E___]Q0<'!P=!0/`(XS#P```$IPG_\+F``/"G^_]0UP?P`/``Z^_P
MH``D07#PH*=I``"G60``P"```$[1XR`@```$P.7___ZC```'!P<'!P?`$```
M3PC`(```3P6Y(``2!X[$&```3INY`@`1!XX'\<`@``!.^,`0``!.];D)`!+K
M(0`#``KK,0`_``RY"``RZS,``0`*N0(`,P>.Q!@``$Z"N0(`$0>.P"```$[<
M!_'KO_!8`"3`L```3M7C\/]@_W&5`+``IW0`%<`0``!.>^,0$````J>$``C$
M*```3H?`Y?___-3`Y?___[62`;``Z[_P^``$!_[`]/___[P'!^MO\#``)./P
M_V#_<;D"`(*GA`!:Q!@``$XVXW`0```"IX0`4KD$`&/C$(```)2Y!`"8E0"`
M`*>$`$^G'@`]IX0`"T&0D`'C$)```)25`)``IW3_]1N8XZ!P```"IX0`'[D4
M`)FY!`"WN00`2;D$`#BY!``JP.7___O:$B*G=``(01F@`)4]$`"GA``/0;"P
M"..@L````J=T_^FY!``JZV_PT``$!_Y!J:`!N>EP&[D$`"KK$0`#``I0$&``
MZV_PT``$!_ZGJ0``N00`*NMO\-``!`?^IY@``*?T_[\'!P<'ZZ_P4``DX_#^
MR/]QLD\`L+D$`*+KNP`@``U!,/"@LD\`L=('\3"P*,#E___\\!(BIW0`'Q@2
M6"#PN,`K``#P`*<N0`"GA``'PBT``*``IW0`$KD$`"JG.0`"P.7___U7$!*G
M&O__B!``'Z?T``2G&```N10`(=4'\3"P**=T``;KK_&(``0'_L#E___\D`<'
MZV_P,``DX_#^P/]QLD\`H.NJ`"``#;)/`*&Y`@!BT@?Q.*`HIX0`!I4`8`"G
M=``+U0?Q.*`HIW0`D^MO\7``!`?^P.7___U+N0(`LJ>$__*Y!``KP.7___O2
MN0(`(J>$`&1!D"`3E2X@$Z=T``:5`)`!IX3_[Y4N(!.GA`!BIP@``+D$`!:G
M*0``LEX`(:<4__ZY!``YIQD``+D)`":R7@`3IQ3__KD)`!D:(:<J``*Y%``B
MP.7___IRXY#PH``DP%```!M.N00`DJ=)__^G.0`!P.7___SCN00`*4$P\*C`
MY?__^RRG+O__N00`*:>$``M8$/#`P!L``/``IQY``*>$`"G`Y?___$JY!``I
MP.7___R%N00`*\#E___[<+D"`"*G=/^@N00`*\#E___Z![D$`";`Y?__^F*G
M]/][E2Z0`:=T_YZ5`)`"IX3_@Z?T_YC`Y?___U>G]/_9P.7___O>!P<'!P<'
MZW_P.``DX_#_6/YQXQ#PH`%QN00`HKD$`).R3P"P08#PH.N[`"``#;D$`#BR
M3P"QITD/_\`@```:X]('$`"P*,#E___ZJ!(BI\0`$>P2__\`V!A"N10`(4$B
M\*"5`"``IW0`(A(1IW0`'L`0``!,L^,0$```!+D$`$FY!``ZXR&P```$P.7_
M__I&XQ#PH`%QU0<0`+`HIW0`*NM_\.`!!`?^&$&Y%`!TISD`+[D$`$>Y!``H
MP.7___I^N0(`(J>$_];`$```3(?C$!````2Y!`!7N00`2+D$`#KC(;````3`
MY?__^QBG]/_2P.7___MCZV_P,``DX_#_2/]QLD\`8.MF`"``#;)/`&&Y!`"R
MN00`H]('\+!@*)4],`"G=``$0:`P`:<(``"Y!``:IXD``+)>`(&G%/_^N0D`
MBD$P\*RY!``KP.7___WRN0(`(J>$`)VG"```IQD``+D$`#*R7@`3IQ3__KD)
M`!*Y(0"!I\0`>N-P\*P`%,38``!,&.MW``,`#>,@L```E+D$`!N5`+``IW0`
M#:?T`.Y!$!`!XR`0``"4E0`0`*>$``:G+@`]IW3_];D)`!NY%``102@0`KD$
M`)?CD-````C`Y?__^3/C()```"2Y`@`BIX0`.^,0L```D.,@T```!.,W(```
M!$(0,`!!L+`!&$&Y`@`1IW0`$*?T`#_C$+```)!"$"`!0;"P`1A!N0(`$:>$
M`#-"0/"@N00`(Y4]\*!!,#`!IW3_[)(](`"G&0``XS&@``"00C$@`:<;``&Y
M`@`SIW3_]]4'\+!@**=T`)CK;_#H``0'_J<9``#C,:```)!",2``IQL``;D"
M`#.G=/_WI_3_ZKD$`".G]/_7Q-@``$N0XW#0```$XQ!P```"IX0`<+D$`!>G
MF```&"FGF@`!01`0".,P$````J=T__BG*@`#N10`(NLB``,`#<`0``!+Y.,0
M$```$J=T`#?`$```2]SE3!````'`Y?__^*:Y`@`2XQ#PH``DIX3_KKD$`#>Y
M%`!YZW<``P`-N00`1\#E___Y$^,0\*``!.,0T```)%"0\*SC$/"@``2GF@`!
MN10`F>N9``,`#4$9$`#E2!````"G]/\CN00`,KD$`"?`Y?__^6/C(/"@`"3C
M(-```"2Y`@`BIX3_>+D4`'GK=P`#``VG]/_7IQD``*?T_R.G*0`0IY@``*?T
M_Z/`Y?__^A4'!P<'P!```$L@P%```#F9Q$@``$L>ZV_P,``DP#```!DQX[`0
M```$X_#_6/]QLD\`H.NJ`"``#;)/`*'C*Z````3`8```&FO`Y?__^KZY!`!6
MY4CPH```P$````H"XRN@```$P#```!D;P.7___DMZV_PV``$!_X'!P<'P!``
M`$KDLD\`(.,0$```!.LB`"``#<!0```Y5;)/`"'$2```2MCC(2````3`,```
M&.O`]/__^HOK;_`P`"3C\/](_7'C$/"P`G&R3P"0ZYD`(``-LD\`D=('$`"0
M*$&P\*[C@/"O`7'`Y?__^7#`$```&.GC$/"@`"2Y!`!BP%```!C;ITD0`:<Y
M``&Y!``KP.7___I,N00`*[D$`#BG21``P.7___AS$B*G1``MN00`LJ<J``&Y
M%``BP.7___>WN0(`HJ>$`""Y%`"[N00`.+D$`$O`Y?__^GI!&Z``D@`0`.,0
M\+`"<=4'$`"0**=T``BY!``JZV_PZ`($!_[`Y?__^56GJ0``I_3_[0<'!P?`
M]/___Y0'!^MO\#``)./P_K#^<>,0\4@!<;D$`+*Y!`"3LD\`<$$P\+3K=P`@
M``W`(```&(.R3P!QT@<0`'`HP.7___OHISD`+[D$`**Y!``KP.7___DSN0(`
M(J>$`!C`(```&'"Y!``[P.7___VWN00`*^,0\4@!<=4'$`!P**=T`-/K;_&`
M`00'_KD$`"G`Y?__^$3`,```&%S`Y?__]XZY`@!BIX3_W4&0\4A!@/"XE0!@
M`*>$`(JY`@"JIX0`#J<(``"Y!``6N00`*K)=`!*G%/_^IX0`:KD$`!:G"```
MIRD``+)>`"&G%/_^XQ`O__]QN0D`)KGI8#&Y(0!AIZ0`&94O$`"G=``)D@`0
M`.,0'___<:<W__>G"```IRD``+D$`!:R7@`AIQ3__KD)`":G"```IQD``+D$
M`#NR7@`3IQ3__KD)`!M!$2`!PAX```__IR3_AL`0```7_..P\*@`).,0\*``
M),!0```87:=)$`"G.0`!N00`*<#E___Y3KD$`#BY!``IP.7___>7$B*G=``,
M6!#PT,`;``#P`,(=``"``*>$`"?`,```%]*G*0``P.7___<"N0(`8J>$_U&5
M`&``IW3_>KD"`*JGA``&E2Z@`*>$``FG*0`!P&```!>KI_3_IY4`H`&GA/_?
MI_3_]:<Y``&Y!``IP.7___C^$B*G=/_3N00`.<`@```7FL#E___\X[D$`"G`
MY?__]WZG]/\IP.7___@Y!P<'!^N_\%@`)*<Y`"_C\/]@_W&Y!`"RP.7___C*
MN0(`(J>$``1!L"`!N00`*^N_\/@`!,#T___W7`<'ZY_P2``DX_#_6/YQLD\`
MH.,0\*`!<>NJ`"``#;)/`*'2!Q``H"BY`@`RIX0`594`,`"GA`!1IP@``*>9
M``"Y!``3LEX`D:<4__ZY"0"3[$D``0#9PDX``!``IR0`4D&P\*"Y!``KP.7_
M__CUXQF___]QN>FP(;DA`!NGQ``-E2\0`*=T``F2`!``XQ`?__]QIR?_]Z<Y
M`"^Y!``KP.7___AJN0(`(J>$`!>Y(0`KIR0`)+D$`"O`Y?__]OWC$/"@`7'5
M!Q``H"BG=``?ZY_P\`$$!_[C$/"@`7'5!Q``H"BG=``3P"```!;TZY_P\`$$
MP/3___;@D@`@`*?T_]RG*0``I_3_W<#E___WE0<'!P?KK_!0`"3C\/]0_W&R
M3P"@0;#PI.NJ`"``#;)/`*'2!_"HH"BY!``[P"```!;9P.7___HUN0(`(J>$
M`##$*```2&[C$/"D`!3K$0`#``WC$"````CC(!`(``3C(!```"2Y`@`BIX3_
MX.,@$!``!.,@$`@`)$$0$`BY`@`BIW3_]KD$`#O`(```%JO`Y?__^@>Y`@`B
MIW3_U+D$`#O`(```%J3`Y?__^?NY`@`BIX0`,,0H``!(-.,0\*0`%.L1``,`
M#>,0(```".,@$`@`!.,@$```)+D"`"*GA/_@XR`0$``$XR`0"``D01`0"+D"
M`"*G=/_VN00`.\`@```6=L#E___YS;D"`"*G=/_4N00`.\`@```6;L#E___Y
MP;D"`"*GA``PQ"@``$?ZXQ#PI``4ZQ$``P`-XQ`@```(XR`0"``$XR`0```D
MN0(`(J>$_^#C(!`0``3C(!`(`"1!$!`(N0(`(J=T__:Y!``[P"```!9`P.7_
M__F3N0(`(J=T_]2Y!``[P"```!8YP.7___F'N0(`(J>$`##$*```1\#C$/"D
M`!3K$0`#``WC$"````CC(!`(``3C(!```"2Y`@`BIX3_X.,@$!``!.,@$`@`
M)$$0$`BY`@`BIW3_]KD$`#O`(```%@O`Y?__^5FY`@`BIW3_U+D$`#O`(```
M%@/`Y?__^4VY`@`BIX0`,,0H``!'AN,0\*0`%.L1``,`#>,0(```".,@$`@`
M!.,@$```)+D"`"*GA/_@XR`0$``$XR`0"``D01`0"+D"`"*G=/_VN00`.\`@
M```5U<#E___Y'[D"`"*G=/_4N00`.\`@```5T<#E___Y$[D"`"*GA``PQ"@`
M`$=,XQ#PI``4ZQ$``P`-XQ`@```(XR`0"``$XR`0```DN0(`(J>$_^#C(!`0
M``3C(!`(`"1!$!`(N0(`(J=T__:Y!``[P"```!6CP.7___CEN0(`(J=T_]2Y
M!``[P"```!5OP.7___C9N0(`(J>$`##$*```1Q+C$/"D`!3K$0`#``WC$"``
M``CC(!`(``3C(!```"2Y`@`BIX3_X.,@$!``!.,@$`@`)$$0$`BY`@`BIW3_
M]KD$`#O`(```%4'`Y?__^*NY`@`BIW3_U+D$`#O`(```%6/`Y?__^)^Y`@`B
MIX0`,,0H``!&V.,0\*0`%.L1``,`#>,0(```".,@$`@`!.,@$```)+D"`"*G
MA/_@XR`0$``$XR`0"``D01`0"+D"`"*G=/_VN00`.\`@```5-<#E___X<;D"
M`"*G=/_4N00`.\`@```5+L#E___X9;D"`"*GA``PQ"@``$:>XQ#PI``4ZQ$`
M`P`-XQ`@```(XR`0"``$XR`0```DN0(`(J>$_^#C(!`0``3C(!`(`"1!$!`(
MN0(`(J=T__:Y!``[P"```!4`P.7___@WN0(`(J=T_]2Y!``[P"```!3YP.7_
M__@KN0(`(J>$`##$*```1F3C$/"D`!3K$0`#``WC$"````CC(!`(``3C(!``
M`"2Y`@`BIX3_X.,@$!``!.,@$`@`)$$0$`BY`@`BIW3_]KD$`#O`(```%,O`
MY?__]_VY`@`BIW3_U+D$`#O`(```%(S`Y?__]_&Y`@`BIX0`,,0H``!&*N,0
M\*0`%.L1``,`#>,0(```".,@$`@`!.,@$```)+D"`"*GA/_@XR`0$``$XR`0
M"``D01`0"+D"`"*G=/_VN00`.\`@```47L#E___WP[D"`"*G=/_4N00`.\`@
M```4BL#E___WM[D"`#*GA``(P"```!1VP.7___F1N00`.\`@```4@<#E___W
MI;D"`#*GA``(P"```!2`P.7___E_N00`.\`@```4?L#E___WD[D"`#*GA``9
MP"```!0?P.7___EMU0?PJ*`HIW0`(L`P```4>L`@```4,>NO\0``!,#T___Y
M7+D$`#O`(```%&/`Y?__]W"Y`@`RIX3_Y<`@```4*L#E___Y2J?T_]W`Y?__
M]*4'!P<'Z[_P6``DX_#_4/]QLD\`L.N[`"``#;)/`+'$+0``1<>G+O__T@?P
MJ+`HIX0`#;D4`"+5!_"HL"BG=``IZ[_Q"``$!_Y!,/"DP"```!/YP.7___<U
MN0(`(J>$`!6_$2``IX0`$<`7````,+F$`!&Y`P`A["(_OP%5Q"\``$68I_3_
MV*<H``"G]/_YP.7___1;Z^_P<``DX_#_8/]QP.7___(RP.7___(/N0(`(J>$
M``7C("````3K[_$0``0'_@<'ZV_P,``DX_#_0/]QLD\`H+D$`&+KJ@`@``U!
M,/"TLD\`H<`@```3Y=('\+B@*,#E___VY;D"`+*GA``8E0"P`*>$`!2Y!``V
MP.7___),N0(`(J>$`!O5!_"XH"BG=`!4ZV_P\``$!_[5!_"XH"BG=`!+N00`
M-L`@```3N^MO\/``!,#T___XGZ<(``"Y!``6N00`.[)>`"&G%/_^IQD``+D)
M`":R7@`3IQ3__KD)`!M!(A`"P.7___(FP!```!,^X[#PJ``DXQ#PH``DN00`
MLL!0```3GJ=)__^G.0`!P.7___21U0?PN*`HIW0`#;D$`#O`(```$WWK;_#P
M``3`]/__^&'`Y?__\[X'!P<'!P>R3P`PZS,`(``-LD\`,>MO\#``)./P_?CW
M<>,P\,``),`0``!$W.-`\@`(<;D$`))!H/#,T@=``#`HT@_PT!`(P"```!+G
MN00`.M('\.`0&-(O\0`0(-(/\.@04-('\/@08,#E___V0[D"`+*GA``&E0"P
M`*=T`F3`Y?__\5S`Y?__\3FY`@`BIX0!'>.P(````J>$`1BG"```IRD``+D$
M`!NR7@`AIQ3__KD)`"OK(@`!``VG*P`!P.7___&<E0"P`.-@L```E+D$`'*Y
M!`""IX0`&[D4`&:Y!``GP%```!,,ITG__Z<Y``'`Y?__]`-!L+`!07!P`N-@
ML```E)4`L`"G=/_I06#Q",`@```2T:?T``FG:P`(XR!O^/\"IX0`'KD$`#K`
MY?__]>&Y`@"RIX3_\I4`L`"GA/_NP.7___9&$B*GA/_HN00`*\#E___R4KD"
M`&*G=``<0;#PT.-@L````J>$`!65`&``IX0`I[D$`";`Y?__]BH2(J=T`)*G
MNP`(XV"P```"IW3_[Z<(``"Y!``6I]D``+)>`-&G%/_^N00`**<9``"Y"0#6
MLEX`$J<4__ZY"0`8&M&GV@0$N10`?;D$`"?`Y?__\13`$```$IOC$/"H`"3C
M@/"P`"3`$```$B3C$/"@`"2Y!`""P%```!*%ITG__Z<Y``'`Y?__\WFY!``H
MISD!P,#E___R<J<N__^G=``+P.7___([6!`@`*<>`!&G=`%P03#Q,+D$`"C`
MY?__\LX8LA(BIW0`"U@0\4C`&P``\`"G'D``IX0`?L08``!#LKD$`&CC4)``
M``3`0```$G'C(!````2G.0`!P.7___*>IWD``.,0\,``!.,@\@`(<=4'(``0
M**=T`H>Y!``GZV_R.`@$!_ZGNP`(N00`)L#E___QI+D"`&*GA/]6I_3_;*=I
M``"G]/]H08#PZ.,@@````J>$`!:Y!``ZP.7___4*N0(`$J>$``:5`!``IW0`
M&:>+``CC((````*G=/_NIRD`#<"P```1^,#E___P=Z=H`%.Y!`!RN00`@J?T
M_N#`Y?__\6RY`@"RIX3_Y*<(``"G*0``N00`&[)>`"&G%/_^N0D`*^LB``$`
M#:<K``&G]/ZX6&#Q3,#E___O\!EBIW3_?E@0\4C`&P```?^G'@'`IW3_=;D$
M`"?`Y?__\#^Y!``ZN00`<L`@```2#<#E___TL;D"`#*GA`#LXR"0```$P.7_
M__BCN0(`8J>$`.*G"```IQD``+D$`":R7@`2IQ3__KD)`!:G'@`#I\0`'KD4
M`"'`,```$>KC(F_\_W&R70`RIQ3__J=T`!"G'@`$IX0!@J<:__NY%``101%@
M`)4O$`"GA`%XQ!T``$+LIQ[__Z>$`5(2$:>$`+?`,```$6/`(```$2C`Y?__
M]DBY!`!HP.7___%SP!```!(:XQ#PL``DXR#PJ``DP!```!#SP%```!&ZXQ#P
MH``DITG__Z<Y``&Y!``GP.7___)(I_0`,L#E___Q$U@0(`"G'@`1IW0`-*>Z
M``&Y!`!HP.7___%&P!```!'MXQ#PN``DXR#PJ``DP!```!#&XQ#PH``DP%``
M`!&1N10`&Z=)___C$/"P`"2G.0`!N00`)\#E___R%J<Y`<"Y!``GP.7___$/
MIR[__Z>$_\>Y!``HP.7___'&N00`-\`@```0D,#E___UWKD$`"?`Y?___/FG
M]/Z]N10`$>,0\*``)+D$`&C$&```0E'C4)````3`0```$/3C(!````2G.0`!
MP.7___$_I_3^H<#E___\VN,0\,``!.,@\@`(<=4'(``0**=T`26Y!``KZV_R
M.`@$P/3___!'XV"0```$I_3_'<`0``!",^5,$````+D$`":G.0``P.7___&%
MN00`DABB$B*GA/]`ITD``J<Y_^[`Y?__[TA!L/(`ITD`!KD$`#NY!``IP.7_
M__$]E0#R`*=T``:50_(!IX0`MKD$`"FG20``ISD``+D4`*K`Y?__[RK`Y0``
M#D^Y!`"2I_0`"[D4`$*Y!``[N00`*<#E```.>J5/@`"Y!``[N00`*L#E___Q
M$1(BIR3_[;D$`"JGN0`4P.7__^['N00`.4$@\<-!H/'7N00`DL#E```.^.-@
MD```D+D$`"K`4```$%:GFP`!ITG__Z<Y``&GJP`"P.7___%)I[?_[<`0```0
M_N,0\+``))(`\?]!$/'7N00`:.,0\*@`),`0```/T>,0\*``),!0```0C:=)
M__^G.0`!N00`)\#E___Q)J?T_QNY!``ZP"````_<P.7___,8N0(`(J>$_UB_
M$2``IX3_5,`7````,+F$`!&Y`P`1ZQ$`/P`,Q!\``$%[I_3^D^,@D`@``J>$
M_H>G"```IQD``+D$`#*R7@`3IQ3__KD)`!+"'@````.GQ/YVXS$O_/]QP!``
M`!!$LET`$Z<4__ZYXH!BI_3^:)5!\@*G=/]*E4/R`Z=T_T:52/($IW3_0I5%
M\@6G=/\^ITD``J<Y_\:Y!``IN00`:,#E___N9KD$`"FG20`IN00`.\#E___P
M7<`0```0=..P\*@`).,0\+``),`0```/3>,0\*``)*?T_WS`Y?__[^D'!P<'
MZW_P.``DP*```$#QXQ"@```$X_#_4/]QLD\`L$&`\*3KNP`@``W`(```#T"R
M3P"QN00`.-('\*BP*..1L```!-(`D+&0L,#E___R?;D"`"*GA``&E3$@`*>$
M`-3`Y?__^";C$*````3CD;````2Y!``IIUD``Z=)``'`,```#]W`Y?__[D2Y
M`@"2IX0`'N,0D!``!.-PH```!.,P$```!.,GL```!,!````/R,#E___N/N,0
MD!``!.,P$```!)%`,`VG=`"VXW"@```$IUD``^,GL```!*=)``'`,```#['`
MY?__[A2Y`@"2IX0`&KD$`#C`(```#K_`Y?__\B2Y`@!"IX0`A>,0D!``!.,G
ML```!.,P$```!,#E___N"..@H```!*=)``'CFK````3`,```#XBY!``IP.7_
M_^TXP$````^+N00`,KD$`"G`Y?__[>[C&K````22`!"QN00`.,`@```.@\#E
M___Q[<0K``!`IKD$`**Y`@`BIX0`+J<Y`<"Y!``JP.7__^[A[!(``0#8PA\`
M```!I\0`%J<N`!&GA``2Q!@``$"&N00`4KD$`$K`(```#V7C,!````3`Y?__
M[U75!_"HL"BG=``ZZW_PZ``$!_[$*```0&W`Y?__^S[$*P``0&NY!`"BN0(`
M(J=T_\?`(```#S/`Y?__[S>5`"`!IX3_-:?T_RK$&```0%+C()`0``3C,!``
M``3C("````3`Y?__\OJG]/]ZXR>P```$P.7__^ZZI_3_1L#E___NQ0<'!P?K
MG_!(`"3C\/]0_W&R3P"@N00`DNNJ`"``#;)/`*'2!_"HH"C`Y?__]I:G.0`O
MN00`LL#E___O1[D"`"*GA``$0;`@`;D$`"O`Y?__[=S$'0``/\VY!`"RIQ[_
M_Z>$`!82$:>$``JY`@"9IX0`!I4`D`"G=``JU0?PJ*`HIW0`1^N?\/@`!`?^
M03#PI,`@```-]\#E___Q,[D"`"*GA``OOQ$@`*>$`"O`%P```#"YA``1N0,`
M$>L1`#\`#,0?```_EJ?T_\^Y!``KITD`!,`P```.(\#E___M)A(BIW3_S=4'
M\*B@**=T`!*Y!``IZY_P^``$P/3___&ZP!```#]WY4P0````I_3_N,#E___N
M.T%0(#BG20`(ZV_P,``DX_#\T/]QLD\`H$$P\*CKJ@`@``VR3P"AT@?S**`H
MXQ!0```$ZP$`(``,XP`P```DP!H`````XQ`P"``D05!0"*<[`!"G1__MXS#Q
M$``$XX#Q&``$XU#Q(``$XY#PJ``$XV#PL``$04#PN*<)`$"Y!`!UX[!````$
MN00`&^,00#``@KF"`!.Y@@`9[%$@OR%5[%$@/@%6XU!`<``DN00`.+D$`):Y
M!`"'ITL`"*<'"USCL"`8``3CD/"P``3"FEJ">9FY"`";XT`@```$XP`@"``$
MXP#PH``DXU`@$``$[#0@OR55ZW```@`,[#0@.@56['``(1Y6[(<@OP!5N>>`
M%;F``!2Y@@`5N>B0T;GGL)6Y@`"0N8(`F^,0\*@`!,(:6H)YF>,0("``"+D(
M`!/K-``"``RY"``9[#0`(1Y6[)$@OP!5N><P9^P1.[\E5;F``&GL&0`Z!5:Y
M@@!HN0@`'>QQ(+\`5>S1.[\E5>S7`#H%5N,0\+@`!.,`\,``!,(:6H)YF<(*
M6H)YF;D(`!6Y"``(N0@`%NN)``(`#.QC(+\`5>R)`"$>5KD(`!VY@@`X[-$[
MOR55[)$@OP!5N>1P$[D$`#WCT/#(``3L.0`Z!5;"VEJ">9FY@@`6N0@`$+GH
M8`VY"``3[&@@OP!5[-$[OR55ZS<``@`,[#<`(1Y6N8(`@^QQ(+\`5;GDD!BY
M!`"-X]#PT``$[(<`.@56PMI:@GF9N8(`%KD(`!"YZ&`-N0@`&.QC(+\`5>S1
M.[\E5>N)``(`#.R)`"$>5KF"`#CLD2"_`%6YY'`3N00`/>/0\-@`!.PY`#H%
M5L+:6H)YF;F"`!:Y"``0N>A@#;D(`!/L:""_`%7LT3N_)57K-P`"``SL-P`A
M'E:Y@@"#['$@OP!5N>20&+D$`(WCT/#@``3LAP`Z!5;"VEJ">9FY@@`6N0@`
M$+GH8`VY"``8[&,@OP!5[-$[OR55ZXD``@`,[(D`(1Y6N8(`..R1(+\`5;GD
M<!.Y!``]X]#PZ``$[#D`.@56PMI:@GF9N8(`%KD(`!"YZ&`-N0@`$^QH(+\`
M5>S1.[\E5>LW``(`#.PW`"$>5KF"`(/L<2"_`%6YY)`8N00`C>/0\/``!.R'
M`#H%5L+:6H)YF;F"`!:Y"``0N>A@#;D(`!CL8R"_`%7LT3N_)57KB0`"``SL
MB0`A'E:Y@@`X[)$@OP!5N>1P$[D$`#WCT/#X``3L.0`Z!5;"VEJ">9FY@@`6
MN0@`$+GH8`VY"``3[&@@OP!5[-$[OR55ZS<``@`,[#<`(1Y6N8(`@^QQ(+\`
M5;GDD!BY!`"-X]#Q```$[(<`.@56PMI:@GF9N8(`%KD(`!"YZ&`-N0@`&.QC
M(+\`5>S1.[\E5>N)``(`#.R)`"$>5KF"`#CLD2"_`%6YY'`3N00`/>/0\0@`
M!.PY`#H%5L+:6H)YF;F"`!:Y"``0N>A@#;D(`!/L:""_`%7LT3N_)57K-P`"
M``SL-P`A'E:Y@@"#['$@OP!5N>20&+D$`(WCT/$0``3LAP`Z!5;"VEJ">9FY
M@@`6N0@`$+GH8`VY"``8[&,@OP!5[-$[OR55ZXD``@`,[(D`(1Y6N8(`..R1
M(+\`5;GD<!.Y!``]X]#Q&``$[#D`.@56PMI:@GF9N8(`%KD(`!"YZ&`-N0@`
M$^QH(+\`5>S1.[\E5>LW``(`#.PW`"$>5KF"`(/L<2"_`%6YY)`8N00`C>/0
M\2``!.R'`#H%5L+:6H)YF;F"`!:Y"``0N>A@#;D(`!CL8R"_`%7LT3N_)57K
MB0`"``SLB0`A'E:Y@@`X[)$@OP!5N>1P$[D$`#WCT/$H``3L.0`Z!5;"VEJ"
M>9FY@@`6N0@`$+GH8`VY"``3[&@@OP!5[-$[OR55ZS<``@`,[#<`(1Y6N8(`
M@^QQ(+\`5;GDD!BY!`"-X]#Q,``$[(<`.@56PMI:@GF9N8(`%KD(`!"YZ&`-
MN0@`&.QC(+\`5>S1.[\E5>N)``(`#.R)`"$>5KF"`#CLD2"_`%6YY'`3N00`
M/>/0\3@`!.PY`#H%5L+:6H)YF;F"`!:Y"``0N>A@#;D(`!/LV""_`%7K-P`"
M``SL-P`A'E:YYS!HXX#Q0``$PHI:@GF9['$[OR55N8``:>QQ(#H%5KF"`&W`
M&@````"Y"`!@N>C0".R#(+\`5;D(`&?K>0`"``SL>0`A'E;LECN_)56YYW#3
M[)8@.@56N8``T>,P\4@`!+F"`-C".F[9ZZ&Y"``XZX$``@`,[($`(1Y6N>>`
M%[F"`!:Y"`#0N1H`,;D(`-GLG3N_)57LG2`Z!5:SP0`)L\T`$+D(`#'L$SN_
M)57L$R`Z!5;CD/%0``2SP0`!PIINV>NAN1H`E^QV(K\^5>QV`B$>5KGG<!BY
M@@`=[&TBOSY5N1H`D>QM`B$>5K/-`!"Y"`"1XQ#Q6``$PAINV>NAN1H`&.S9
M.[\E5>S9(#H%5KGG8(>Y@@"#N1H`&+D(`!WLT3N_)57LT2`Z!5;C@/%@``2S
MP0`-PHINV>NAN1H`A^QS(K\^5>QS`B$>5KGG<-:Y@@#9L\T``+D:`(WC,/%H
M``3".F[9ZZ&Y&@`V[&DBOSY5[&D"(1Y6N>=@U[F"`-&Y"`"`N1H`/>R8.[\E
M5>R8(#H%5K/!``FSS0``N0@`,.S3.[\E5>S3(#H%5N.0\7``!+/!``W"FF[9
MZZ&Y&@"7['$BOSY5['$"(1Y6N>=PUKF"`-BSS0``N1H`G>,0\7@`!,(:;MGK
MH;D:`!;L:"*_/E7L:`(A'E:YYV#7N8(`T[D(`)"Y&@`=[(D[OR55[(D@.@56
ML\$`"+/-``"Y"``0[-$[OR55[-$@.@56XX#Q@``$L\$`#<**;MGKH;D:`(?L
M<R*_/E7L<P(A'E:YYW#6N8(`V;/-``"Y&@"-XS#QB``$PCINV>NAN1H`-NQI
M(K\^5>QI`B$>5KGG8->Y@@#1N0@`@+D:`#WLF#N_)57LF"`Z!5:SP0`)L\T`
M`+D(`##LTSN_)57LTR`Z!5;CD/&0``2SP0`-PIINV>NAN1H`E^QQ(K\^5>QQ
M`B$>5KGG<-:Y@@#8L\T``+D:`)WC$/&8``3"&F[9ZZ&Y&@`6[&@BOSY5[&@"
M(1Y6N>=@U[F"`-.Y"`"0N1H`'>R).[\E5>R)(#H%5K/!``BSS0``N0@`$.S1
M.[\E5>S1(#H%5N.`\:``!+/!``W"BF[9ZZ&Y&@"'[',BOSY5[',"(1Y6N>=P
MUKF"`-FSS0``N1H`C>,P\:@`!,(Z;MGKH;D:`#;L:2*_/E7L:0(A'E:YYV#7
MN8(`T;D(`("Y&@`][)@[OR55[)@@.@56L\$`";/-``"Y"``P[-,[OR55[-,@
M.@56XY#QL``$L\$`#<*:;MGKH;D:`)?L<2*_/E7L<0(A'E:YYW#6N8(`V+/-
M``"Y&@"=XQ#QN``$PAINV>NAN1H`%NQH(K\^5>QH`B$>5KGG8->Y@@#3N0@`
MD+D:`!WLB3N_)57LB2`Z!5:SP0`(L\T``+D(`!#LT3N_)57LT2`Z!5;C@/'`
M``2SP0`-PHINV>NAN1H`A^QS(K\^5>QS`B$>5KGG<-:Y@@#9L\T``+D:`(WC
M,/'(``3".F[9ZZ&Y&@`V[&DBOSY5[&D"(1Y6N>=@U[F"`-&Y"`"`N1H`/>R8
M.[\E5>R8(#H%5K/!``FSS0``N0@`,.S3.[\E5>S3(#H%5N.0\=``!+/!``W"
MFF[9ZZ&SS0``N1H`E^QQ(K\^5>QQ`B$>5KGG<-:Y@@#8XQ#QV``$N1H`G<(:
M;MGKH;D(`)"Y&@`6[-@BOSY5[&D@OP!5[-@"(1Y6[`D[OR55N>?0A^P&`#H%
M5KF"`(.Y&@`8N0@`$.R#(K\^5>R#`B$>5N,P\>``!+GG@`W".F[9ZZ&Y@@"0
MN1H`-^QQ(+\`5>P1.[\E5>P7`#H%5KD:`#GCD/'H``2Y"``QPIJ/&[S<ZQ8`
M`@`,N1H`G>P6`"$>5NS1(+\`5;GDT`BSP0`I[&,[OR55[),@OP!5N>80.+F`
M`#>Y@0`PXP#Q\``$P@J/&[S<[&D`.@56L\$``+/-``*Y"``PL\T``+D(`#:Y
M&@`(ZV<``@`,[&<`(1Y6N>30=KF!`!:Y@``9N8$`%^-P\?@`!+D(`!#">H\;
MO-RYZ-`'[(,@OP!5L\$`(.PS.[\E5>PX`#H%5KD(`#'K&0`"``SL&0`A'E;L
MT2"_`%6YY-`&N>80EKF``)BY@0"0XP#R```$P@J/&[S<L\$``.QS(+\`5;/-
M``*Y"`"0[#,[OR55L\T``+D:``;K:``"``SL:``A'E:YY-"&[#<`.@56N8$`
M%KF``!>Y@0`8XX#R"``$N0@`$,**CQN\W+GHT`BY"`"3L\$`(.PY(+\`5>N'
M``(`#.R9.[\E5>R'`"$>5NR3`#H%5NQX(+\`5;D(`!FYY'`&[-$@OP!5[)$[
MOR55N>:`%NR=`#H%5KF``!.Y@0`0XP#R$``$P@J/&[S<L\$``+/-``*Y"``0
MN0@`&>N3``(`#.R3`"$>5KGFD#BYY'")N8``/;/-``"Y@0`XN1H`!NQA(+\`
M5;D(`##L$3N_)57L%@`Z!5:Y"``Q[(,@OP!5ZQT``@`,[!T`(1Y6N>80";/!
M``#L,SN_)57C`/(8``3L.``Z!5;""H\;O-RSP0`CN00`,+D(`#>SP0!#L\T`
M!.S1(+\`5;/-`#"YY-!YN8``-KF!`#>Y"``PL\T``N-P\B``!+D(`##">H\;
MO-RY&@!YZY8``@`,L\$`!^R6`"$>5K/-``"YY-!IN8$`&;F``!BY@0`6XV#R
M*``$N0@`$,)JCQN\W+GHT`;L<R"_`%6SP0`@[#,[OR55[#<`.@56N0@`,>L8
M``(`#.P8`"$>5NS1(+\`5;GDT`GL8R"_`%7L@SN_)56YYA`YN8``-[F!`##C
M`/(P``3""H\;O-RSP0``L\T``KD(`#"SS0``N1H`">N7``(`#.R7`"$>5KGD
MT'GLA@`Z!5:Y@0`9N8``%KF!`!?C</(X``2Y"``0PGJ/&[S<N>C0![D(`#BS
MP0`@[(,@OP!5[#,[OR55[#@`.@56N0@`,>L6``(`#.P6`"$>5NS1(+\`5;GD
MT`GL<R"_`%7L8SN_)56YYA`YN8``.+F!`##C`/)```3""H\;O-RSP0``L\T`
M`KD(`#"SS0``N1H`">N8``(`#.R8`"$>5KGDT(GL9P`Z!5:Y@0`9N8``%[F!
M`!CC@/)(``2Y"``0PHJ/&[S<N>C0"+D(`#:SP0`@[&,@OP!5[#,[OR55[#8`
M.@56N0@`,>L7``(`#.P7`"$>5NS1(+\`5;GDT`GL@R"_`%7L<SN_)56YYA`Y
MN8``-KF!`##C`/)0``3""H\;O-RSP0``L\T``KD(`#"SS0``N1H`">N6``(`
M#.R6`"$>5KGDT&GL>``Z!5:Y@0`9N8``&+F!`!;C8/)8``2Y"``0PFJ/&[S<
MN>C0!KD(`#>SP0`@[',@OP!5[#,[OR55[#<`.@56N0@`,>L8``(`#.P8`"$>
M5NS1(+\`5;GDT`GL8R"_`%7L@SN_)56YYA`YN8``-[F!`##C`/)@``3""H\;
MO-RSP0``L\T``KD(`#"SS0``N1H`">N7``(`#.R7`"$>5KGDT'GLA@`Z!5:Y
M@0`9N8``%KF!`!?C</)H``2Y"``0PGJ/&[S<N>C0![D(`#BSP0`@[(,@OP!5
M[#,[OR55[#@`.@56N0@`,>L6``(`#.P6`"$>5NQA(+\`5;GD8`GL<R"_`%7L
MTSN_)56YYA`YN8``.+F!`##C`/)P``3""H\;O-RSP0``L\T``KD(`#"SS0``
MN1H`">N8``(`#.R8`"$>5KGD8(GLUP`Z!5:Y@0`9N8``%[F!`!CC@/)X``3"
MBH\;O-RY"``0N0@`/;GH8`CLTR"_`%7L,SN_)57L/0`Z!5:Y"``Q[(,[OR55
M[(,@.@56ZQ<``@`,L\$`".P7`"$>5NR!(+\`5;GD@&FYYA!YN8``?;F!`';C
M8/*```2Y"`!PPFJ/&[S<L\T``+D:`&FYZ`"7L\$`)NM]``(`#.QI.[\E5>Q]
M`"$>5NQI(#H%5KGD@`?`.@````"Y!`#6N8$`%^-@\H@`!+F``!/":LIBP=:Y
M@0`0N>B`!N-@\I``!+/!``#":LIBP=:SS0`"N1H`9[D(`!#K@P`"``RY"``=
M[(,`(1Y6L\T``+GG@-?L,3N_)56Y@@#9[#$@.@56N1H`#;/!`":Y"``P[&,[
MOR55[&,@.@56['DBOSY5L\$`1NQY`B$>5N/0\I@`!+GG<&C"VLIBP=:Y@@!A
MN1H`V+/-``2SP0`-L\T`DKD:`);L82*_/E7L80(A'E:YYV#7N8(`T[D(`)"S
MS0``[!D[OR55N1H`#>P9(#H%5KD(`!#LT3N_)57LT2`Z!5;C@/*@``2SP0`-
MPHK*8L'6N1H`A^QS(K\^5>QS`B$>5KGG<-:Y@@#9L\T``+D:`(WC,/*H``3"
M.LIBP=:Y&@`V[&DBOSY5[&D"(1Y6N>=@U[F"`-&Y"`"`N1H`/>R8.[\E5>R8
M(#H%5K/!``FSS0``N0@`,.S3.[\E5>S3(#H%5N.0\K``!+/!``W"FLIBP=:Y
M&@"7['$BOSY5['$"(1Y6N>=PUKF"`-BSS0``N1H`G>,0\K@`!+D(`)#"&LIB
MP=;LV3N_)56Y&@`6[-D@.@56[&@BOSY5[&@"(1Y6N>=@A[F"`(.SP0`-N1H`
M&+/-``#CT/+```2Y"``0PMK*8L'6[($[OR55N1H`U^R!(#H%5NQS(K\^5;/!
M``CL<P(A'E:SS0``N>=PAN,P\L@`!+F"`(G".LIBP=:Y&@`VN00`;>S9(K\^
M5;D:`&BY"`!@[-D"(1Y6N>?0E[F"`)'LACN_)56Y&@`YN00`F.R6(#H%5KD(
M`#GC@/+0``3LDSN_)57LDR`Z!5;"BLIBP=:SP0`)N1H`A[/-``#L<2*_/E7L
M<0(A'E;C$/+8``2YYW"=PAK*8L'6N8(`EKD:`!WLUB*_/E7LU@(A'E:YY]!G
MN8(`8[D:`(FY&@`6N0@`@.R8.[\E5>R8(#H%5K/!``FSS0``N0@`$.QA.[\E
M5>QA(#H%5N.0\N``!+/!``;"FLIBP=:Y&@"7[',BOSY5[',"(1Y6N>=P;;F"
M`&BSS0``N1H`EN,P\N@`!.QH(K\^5<(ZRF+!UNQH`B$>5KD:`#VYYV#7N8(`
MT;D(`)"Y&@`][(D[OR55[(D@.@56L\$`"+/-``"Y"``P[-,[OR55[-,@.@56
MXX#R\``$L\$`#<**RF+!UKD:`(?L<2*_/E7L<0(A'E:YYW#6N8(`V;/-``"Y
M&@"-XQ#R^``$PAK*8L'6N1H`%NQI(K\^5>QI`B$>5KGG8->Y@@#3N0@`@+D:
M`!WLF#N_)57LF"`Z!5:SP0`)L\T``+D(`!#LT3N_)57LT2`Z!5;CD/,```2S
MP0`-PIK*8L'6N1H`E^QS(K\^5>QS`B$>5KGG<-:Y@@#8L\T``+D:`)VY"`"0
M[-D[OR55[-D@.@56XS#S"``$L\$`#<(ZRF+!UK/-``"Y&@`VX]#S$``$[&@B
MOSY5PMK*8L'6[&@"(1Y6N1H`U[GG8(>Y@@"!N1H`.+D(`##L<SN_)57L<R`Z
M!5;L@2*_/E6SP0`'[($"(1Y6L\T``+GG@':Y@@!YN1H`U^,0\Q@`!.QY(K\^
M5<(:RF+!UNQY`B$>5KD:`!:YZ`!MN>=P"+D$`-?CT"`@``C`V@````#CT"`@
M`"3LEB"_`%6YYS#0[`8[OR55N1H`'>P)`#H%5KD(`!#LTR*_/E7LTP(A'E;C
M,/,@``2YY]`'PCK*8L'6N>BP?;D(`#2YYV"P[$$@OP!5N1H`..R!.[\E5;D$
M`!/LA``Z!5:Y&@`;N0@`&,`:`````.,0(```),!Z`````.-P(!@`).,P\*``
M!.L9``(`#+D(`#3L&0`A'E;`.@````#C,"`(`"2Y"``5P!H`````XQ`@$``D
MU0?S**`HIW0`"NMO\V``!`?^N00`:Z?T](/`Y?__XGOK[_!P`"2G*0"`X_#_
M8/]QP.7__^"PP#%G12,!XS`@```DY4@@*```P#_OS:N)XS`@"``DY4@@,```
MP#^8NMS^XS`@$``DY4P@>```P#$0,E1VXS`@&``DP#_#TN'PXS`@(``DZ^_Q
M$``$!_X'!P<'ZV_P,``DZQ0``P`-N00`DN,@("@`!+D(`!+L42"_`%6Y!`"$
MX_#_8/]QXT"0,``$N00`L[DQ`"&GQ``$ITL``>-0D"@`).L8`!T`#+D(`!3C
M$)`P`"1!<)`XXR"0>``2IW0`/:>.`#^GQ`!D[&C_P`#8B&``!NP6``$`V.P1
M'[D&5>RA_\``V4'1L`#KJ@`&``RGJP`!TC]P`+``N00`*4&PL$#`Y?__\[:G
MI__VIXK_P(E@``8;AKD4`(BY!``]N00`)[D$`$C`Y?__XNQ0@)!XZV_PT``$
M!_ZGJ`!`&Z(9J+D$`!>Y\C"HN1@`$KD$`#NY!``AN10`:KD$`$;`Y?__XM$8
M&EH0D'A0$)!XIQX`0*=T_^"Y^:"HN0@`MKD4`(JY!``IP.7___-UI_3_G+D$
M`-NG]/_$ZX_P0``DN00`L^.`,"@`!..0,#``!.PX.K\]5;D4`!-!$;`XDH`0
M`*<Z``'C\/]@_W&Y%``3N00`HD$1L#BG/@`XI\0`3J=(`$"Y^3`D&4.GA``/
MIRK__^LR``@`WA(SIW0`8;D6`"+&(````&FY!``KP.7___,SUS>P.+`XIQD`
M`.P9``=@5>P9"`]@5>P9$!=@5>P9&!\@5;D$`"OL@0`?`%7C@+!P`"3`Y?__
M\Q>Y!``KT@.@`+`$T@.@!+`,T@.@"+`4T@.@#+`<T@.@$+`DZX_PX``$P/3_
M_^&XIT@`.+GY,"090Z>$_\NG*O__ZS(`"`#>$C.G=``)N18`(L8@````(*?T
M_[SC(!0``#;7_Q``$`!!$!$`IS;_^*?T_^_C(!0``#;7_Q``$`!!$!$`IS;_
M^*?T_Y?7`!``$`#7`!``$``'!\18```R,,#T___?30<'!P?K;_`P`"2Y!``?
MI_O_8.,0\```),#````Q!@<'XT#Q$``$ZV_PT``$!_0'!P```````@`!)7,O
M)7,`+W!R;V,O<V5L9B]E>&4``$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E
M<@!);G1E<FYA;',Z.E!!4CHZ0D]/5```+W!R;V,O)6DO)7,`97AE`"X`4$%2
M7U1%35```%!!4E]04D]'3D%-10``.@`O`%!%4DPU3$E"``!015),3$E"`%!%
M4DPU3U!4``!015),24\``%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1`!0
M05)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?1TQ/0D%,7T1%0E5'
M``!005)?1TQ/0D%,7U1-4$1)4@!005)?5$U01$E2``!005)?1TQ/0D%,7U1%
M35``4$%27T=,3T)!3%]#3$5!3@``,0!,1%],24)205)97U!!5$@`4UE35$5-
M```E,#)X```E<R5S)7,E<P``<&%R+0``)7,Z(&-R96%T:6]N(&]F('!R:79A
M=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``)7,Z('!R
M:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V
M92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@``4$%42```<&%R;```
M+G!A<@``)7,E<V-A8VAE+25S)7,``"5S)7-T96UP+25U)7,`)7,E<W1E;7`M
M)74M)74E<P``&`!P97)L```P`%!!4CHZ4&%C:V5R.CI615)324].```Q+C`U
M-@!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0``)7,Z(&-R96%T
M:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H
M97)R;F\])6DI"@``+64``"TM``!54T52``!54T523D%-10``5$5-4$1)4@!4
M35``+W1M<```979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K
M(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP
M86-K86=E(%]?<&%R7W!L.PIM>2`H)%!!4E]-04=)0RP@)$9)3$5?;V9F<V5T
M7W-I>F4L("1#04-(15]M87)K97(L("1C86-H95]N86UE7W-I>F4I.PI"14=)
M3B!["B1005)?34%'24,@/2`B7&Y005(N<&U<;B(["B1&24Q%7V]F9G-E=%]S
M:7IE(#T@-#L@("`C('!A8VLH(DXB*0HD8V%C:&5?;6%R:V5R(#T@(EPP0T%#
M2$4B.PHD8V%C:&5?;F%M95]S:7IE(#T@-#`["GT*<W5B(&9I;F1?<&%R7VUA
M9VEC"GL*;7D@*"1F:"D@/2!`7SL*;7D@)&-H=6YK7W-I>F4@/2`V-"`J(#$P
M,C0["FUY("1B=68["FUY("1S:7IE(#T@+7,@)&9H.PIM>2`D<&]S(#T@)'-I
M>F4@+2`D<VEZ92`E("1C:'5N:U]S:7IE.R`@("`@(",@3D]413H@)'!O<R!I
M<R!A(&UU;'1I<&QE(&]F("1C:'5N:U]S:7IE"G=H:6QE("@D<&]S(#X](#`I
M('L*<V5E:R`D9F@L("1P;W,L(#`["G)E860@)&9H+"`D8G5F+"`D8VAU;FM?
M<VEZ92`K(&QE;F=T:"@D4$%27TU!1TE#*3L*:68@*"AM>2`D:2`](')I;F1E
M>"@D8G5F+"`D4$%27TU!1TE#*2D@/CT@,"D@>PHD<&]S("L]("1I.PIR971U
M<FX@)'!O<SL*?0HD<&]S("T]("1C:'5N:U]S:7IE.PI]"G)E='5R;B`M,3L*
M?0IM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE+"`E36]D=6QE
M0V%C:&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@
M1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&
M:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA
M;64H)'!A<E]T96UP*3L*;W5T<RAQ<5M296UO=FEN9R!F:6QE<R!I;B`B)'!A
M<E]T96UP(ETI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I
M(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T
M96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*
M;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A8
M6%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL
M"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIM>2`D9FEL96YA
M;64@/2`D=&UP+3YF:6QE;F%M93L*<')I;G0@)'1M<"`\/"(N+BXB.PIX/3$[
M('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*
M:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P
M(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<D9FEL96YA;64G"BXN+@IC
M;&]S92`D=&UP.PIC:&UO9"`P-S`P+"`D9FEL96YA;64["FUY("1C;60@/2`B
M)&9I;&5N86UE(#XO9&5V+VYU;&P@,CXF,2`F(CL*<WES=&5M*"1C;60I.PIO
M=71S*'%Q6U-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@
M8VQE86YU<#H@)&9I;&5N86UE72D["GT*?2!]"D)%1TE.('L*26YT97)N86QS
M.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/
M5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[
M4$%27T1%0E5'?3L*;7D@)7-Y<R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]
M?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@
M/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D
M96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O
M)RDL"BD["E]S971?<')O9VYA;64H*3L*;W5T<RAQ<5M<)'!R;V=N86UE(#T@
M(B1P<F]G;F%M92)=*3L*7W-E=%]P87)?=&5M<"@I.PIO=71S*'%Q6UPD14Y6
M>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2)=*3L*;7D@*"1S=&%R=%]P
M;W,L("1D871A7W!O<RD["DU!1TE#.B!["FQO8V%L("1324=[7U]705).7U]]
M(#T@<W5B('M].PIU;FQE<W,@*&]P96X@7T9(+"`G/#IR87<G+"`D<')O9VYA
M;64I('L*;W5T<RAQ<5M#86XG="!R96%D(&9R;VT@9FEL92`B)'!R;V=N86UE
M(ETI.R`@(R!D;VXG="!U<V4@)"$@:&5R92!A<R!I="!R97%U:7)E<R!%<G)N
M;RYP;0IL87-T($U!1TE#.PI]"FUY("1M86=I8U]P;W,@/2!F:6YD7W!A<E]M
M86=I8R@J7T9(*3L*:68@*"1M86=I8U]P;W,@/"`P*2!["F]U=',H<7%;0V%N
M)W0@9FEN9"!M86=I8R!S=')I;F<@(B1005)?34%'24,B(&EN(&9I;&4@(B1P
M<F]G;F%M92)=*3L*;&%S="!-04=)0SL*?0IO=71S*")&;W5N9"!005(@;6%G
M:6,@870@<&]S:71I;VX@)&UA9VEC7W!O<R(I.PIS965K(%]&2"P@)&UA9VEC
M7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE+"`P.PIR96%D(%]&2"P@)&)U9BP@
M)$9)3$5?;V9F<V5T7W-I>F4["FUY("1O9F9S970@/2!U;G!A8VLH(DXB+"`D
M8G5F*3L*;W5T<R@B3V9F<V5T(&9R;VT@<W1A<G0@;V8@1DE,17,@:7,@)&]F
M9G-E="(I.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S
M:7IE("T@)&]F9G-E="P@,#L*)&1A=&%?<&]S(#T@=&5L;"!?1D@["FUY("5R
M97%U:7)E7VQI<W0["G)E860@7T9(+"`D8G5F+"`T.R`@("`@("`@("`@("`@
M("`@("`@("`@("`@(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D
M8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L
M("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F
M.PIO=71S*'%Q6U5N<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B+BXN72D["FUY
M("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_
M("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@
M;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E
M860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H
M)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY
M("1F:6QE;F%M92`](%]S879E7V%S*"(D8W)C)&5X="(L("1B=68L(#`W-34I
M.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA
M;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL
M;F%M93L*?0IE;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD
M(&1E9FEN960@)$5.5GM005)?5$5-4'T@*2!["FUY("1F:6QE;F%M92`](%]S
M879E7V%S*"(D8F%S96YA;64D97AT(BP@)&)U9BP@,#<U-2D["F]U=',H(E-(
M3$E".B`D9FEL96YA;65<;B(I.PI]"F5L<V4@>PHD36]D=6QE0V%C:&5[)&9U
M;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^
M("1F=6QL;F%M92P*?3L*)')E<75I<F5?;&ES='LD9G5L;&YA;65]*RL["GT*
M<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H
M)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O
M<B`A)&UO9'5L93L*;7D@)&EN9F\@/2`D36]D=6QE0V%C:&5[)&UO9'5L97T[
M"G)E='5R;B!U;FQE<W,@)&EN9F\["F1E;&5T92`D<F5Q=6ER95]L:7-T>R1M
M;V1U;&5].PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&EN9F\O)&UO9'5L
M92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE
M.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D
M:64@(D-A;B=T(&-R96%T92!T96UP(&9I;&4Z("0A(CL*)&9H+3YB:6YM;V1E
M*"D["B1F:"T^<')I;G0H)&EN9F\M/GMB=69]*3L*)&9H+3YS965K*#`L(#`I
M.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A
M<R@B)&EN9F\M/GMC<F-]+G!M(BP@)&EN9F\M/GMB=69]*3L*)&EN9F\M/GMF
M:6QE?2`]("1F:6QE;F%M93L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1F:6QE
M;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&5N86UE(CH@)"%=.PIR
M971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;B=T
M(&9I;F0@;6]D=6QE("1M;V1U;&4A(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,
M;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V
M>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET
M7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F
M:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL
M97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO
M*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F
M:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA
M;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I
M<F5?;&ES='LD9FEL96YA;65].PI]"G5N;&5S<R`H)&)U9B!E<2`B4$M<,#`S
M7#`P-"(I('L*;W5T<RAQ<5M.;R!Z:7`@9F]U;F0@869T97(@1DE,12!S96-T
M:6]N(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0R`["GT*)'-T
M87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@("`@("`@("`@("`@("`C('-T
M87)T(&]F('II<`I]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L
M("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%
M55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O
M8FQE;2D*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M
M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@
M8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R
M"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD
M("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM0
M05)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA
M;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6
M*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R
M(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#([
M"GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF
M("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF
M("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I
M('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B
M=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`]
M(#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@
M)#(@;W(@9&EE('%Q6T-A;B=T(&]P96X@;&]G(&9I;&4@(B0R(CH@)"%=.PI]
M"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF
M="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE
M=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z
M.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF
M>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*
M=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*
M<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I
M<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@
M)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@)SPZ<F%W
M)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@9FEN9"!P87(@9FEL92`B)'!A<B(Z
M("0A73L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z
M.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P
M87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O
M<B!R96%D:6YG('II<"!A<F-H:79E("(D<&%R(ET["GT*;7D@)6UE=&%?<&%R
M(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT
M<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE
M=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI
M)"]M9SL*?0I].PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)'!H+"`G
M/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!R96%D('!A<B!F:6QE("(D
M<&%R(CH@)"%=.PIM>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@-#L*9&EE('%Q
M6R(D<&%R(B!I<R!N;W0@82!P87(@9FEL95T@=6YL97-S("1B=68@97$@(E!+
M7#`P,UPP,#0B.PIC;&]S92`D<&@["GT*0W)E871E4&%T:"@D;W5T*2`["FUY
M("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4
M*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#
M*"DL"C`W-S<L"BD@;W(@9&EE('%Q6T-A;B=T(&-R96%T92!F:6QE("(D;W5T
M(CH@)"%=.PHD9F@M/F)I;FUO9&4H*3L*<V5E:R!?1D@L(#`L(#`["FUY("1L
M;V%D97(["FEF("AD969I;F5D("1D871A7W!O<RD@>PIR96%D(%]&2"P@)&QO
M861E<BP@)&1A=&%?<&]S.PI](&5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PHD
M;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD
M("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&
M:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY
M*%PD;&]A9&5R+"`D,"D["GT*:68@*"1M971A7W!A<GMC;&5A;GTI('L*;7D@
M)'!A<E]C;&5A;B`]("(],2(["FUY("1P87-S7W!A<E]C;&5A;B`]('5C(")?
M7W!A<W-?<&%R7V-L96%N7U\B.PHD;&]A9&5R(#U^('-[*#\\/21[<&%S<U]P
M87)?8VQE86Y]*2@@*RE]"GLD<&%R7V-L96%N("X@*"(@(B!X("AL96YG=&@H
M)#$I("T@;&5N9W1H*"1P87)?8VQE86XI*2E]96<["GT*)&9H+3YP<FEN="@D
M;&]A9&5R*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!L;V%D97(@=&\@(B1O
M=70B.B`D(5T["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*
M4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR
M97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@
M?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I
M9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF
M:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@9F]R
M96%C:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,
M;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI
M8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@("`@("`@(R!8
M6%@@;&EB7V5X="!V<R!D;&5X="`_"FUY("5W<FET=&5N.PIF;W)E86-H(&UY
M("1K97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M92D[
M"FEF("AD969I;F5D*&UY("1F8R`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[
M)&ME>7TI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("1F8RD["GT*96QS
M92!["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M?%Y<
M421D:7)<12\H+BHI)'QI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("0Q
M*3L*;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N*BDD
M?"D@>PII9B`H;7D@)')E9B`]("1-;V1U;&5#86-H97LD,7TI('L**"1F:6QE
M+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I<B\D
M,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0[
M"GT*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I9B`D
M=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I
M;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;4&%C
M:VEN9R!&24Q%("(E<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65]
M(#H@)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C
M;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]('5N
M9&5F.PIO<&5N(&UY("1T:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q6T-A
M;B=T(')E860@(B1F:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD=&@^.PIC;&]S
M92`D=&@["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT
M+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@
M86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z
M.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D
M;F%M92D["GT*)&9H+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L96YG=&@H
M)&YA;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z
M.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE*2P*<&%C:R@G3B<L(&QE
M;F=T:"@D8V]N=&5N="DI+`HD8V]N=&5N="D*;W(@9&EE('%Q6T5R<F]R('=R
M:71I;F<@96UB961D960@1DE,12!T;R`B)&]U="(Z("0A73L*;W5T<RAQ<5M7
M<FET=&5N(&%S("(D;F%M92)=*3L*?0I]"FEF("@D>FEP*2!["B1Z:7`M/G=R
M:71E5&]&:6QE2&%N9&QE*"1F:"D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2PIO
M<B!D:64@<7%;17)R;W(@=W)I=&EN9R!Z:7`@<&%R="!O9B`B)&]U=")=.PI]
M"B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`D8V%C:&5?
M;F%M95]S:7IE.PII9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H
M<W1A="@D;W5T*2E;.5TI('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H
M,2D["F]P96X@;7D@)'1H+"`B/#IR87<B+"`D;W5T.PHD8W1X+3YA9&1F:6QE
M*"1T:"D["F-L;W-E("1T:#L*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E
M<W0["GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@D8V%C:&5?;F%M95]S:7IE
M("T@;&5N9W1H("1C86-H95]N86UE*3L*)&-A8VAE7VYA;64@+CT@)&-A8VAE
M7VUA<FME<CL*;7D@)&]F9G-E="`]("1F:"T^=&5L;"`K(&QE;F=T:"@D8V%C
M:&5?;F%M92D@+2!L96YG=&@H)&QO861E<BD["B1F:"T^<')I;G0H)&-A8VAE
M7VYA;64L"G!A8VLH)TXG+"`D;V9F<V5T*2P*)%!!4E]-04=)0RD*)B8@)&9H
M+3YC;&]S90IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!T<F%I;&5R(&]F("(D
M;W5T(CH@)"%=.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U
M;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E
M<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*
M<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM
M>2`D9F@@/2!)3SHZ1FEL92T^;F5W.R`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(R!!<F-H:79E.CI::7`@;W!E<F%T97,@;VX@86X@24\Z.DAA;F1L
M90HD9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@<7%;9F1O
M<&5N*"D@9F%I;&5D.B`D(5T["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE
M*"US(%]&2"D["FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"1Z:7`M
M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV
M93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@
M87)C:&EV92`B)'!R;V=N86UE(ET["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3
M:7IE*#8T("H@,3`R-"D["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B10
M05(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PIO=71S*")%>'1R86-T
M:6YG('II<"XN+B(I.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C
M('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D;65M
M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI<T1I
M<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64[
M"FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_
M.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PHH/SHD0V]N9FEG.CI#;VYF
M:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M
M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D
M14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N
M86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2![
M"F]U=',H<7%;4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR
M96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B72D["GT@96QS92!["F]U=',H
M<7%;17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(N
M+BY=*3L**"1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE
M*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!E
M>'1R86-T:6YG('II<"!M96UB97(@=&\@(B1D97-T7VYA;64B73L*8VAM;V0H
M,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU
M;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N
M(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED
M:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*
M)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]0
M4D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS
M=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE
M.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL
M93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U
M:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL
M97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B
M(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,
M;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I
M<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U
M:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R
M=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*
M<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I
M<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD
M;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6([
M"G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PIR
M97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ
M1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@
M4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S
M.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@
M?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U
M:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4
M:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L
M24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@
M=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.
M5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD
M<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH
M;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!4
M14U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N
M;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@[
M"FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E
M='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN
M,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.
M86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D
M<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\
M("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*;7D@)'-T;7!D:7(@/2`B)'!A
M=&@D<WES>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*
M;6MD:7(@)'-T;7!D:7(L(#`W-34["FUY("1C86-H95]D:7(["FEF("@D14Y6
M>U!!4E]#3$5!3GTI('L*)&-A8VAE7V1I<B`](")T96UP+20D(CL*?0IE;'-E
M('L*;W!E;B!M>2`D9F@L("(\.G)A=R(L("1P<F]G;F%M92!O<B!D:64@<7%;
M0V%N)W0@<F5A9"`B)'!R;V=N86UE(CH@)"%=.PII9B`H*&UY("1M86=I8U]P
M;W,@/2!F:6YD7W!A<E]M86=I8R@D9F@I*2`^/2`P*2!["G-E96L@)&9H+"`D
M;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H)&-A8VAE
M7VUA<FME<BDL(#`["FUY("1B=68["G)E860@)&9H+"`D8G5F+"!L96YG=&@H
M)&-A8VAE7VUA<FME<BD["FEF("@D8G5F(&5Q("1C86-H95]M87)K97(I('L*
M<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ90HM(&QE
M;F=T:"@D8V%C:&5?;6%R:V5R*0HM("1C86-H95]N86UE7W-I>F4L(#`["G)E
M860@)&9H+"`D8G5F+"`D8V%C:&5?;F%M95]S:7IE.PHD8G5F(#U^(',O7#`O
M+V<["B1C86-H95]D:7(@/2`B8V%C:&4M)&)U9B(["GT*?0IC;&]S92`D9F@[
M"GT*:68@*"$D8V%C:&5?9&ER*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"([
M"B1%3E9[4$%27T-,14%.?2`](#$["GT*)'-T;7!D:7(@+CT@(B1S>7-[7V1E
M;&EM?21C86-H95]D:7(B.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*)$5.5GM0
M05)?5$5-4'T@/2`D<W1M<&1I<CL*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I
M9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO
M.PI]"G-U8B!?<V%V95]A<R!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D
M92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N
M;&5S<R`H+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA
M;64N)"0B.PIM>2`D9F@["BAO<&5N("1F:"P@)SXZ<F%W)RP@)'1E;7!N86UE
M*0HF)B`H<')I;G0@)&9H("1C;VYT96YT<RD*)B8@*&-L;W-E("1F:"D*;W(@
M9&EE('%Q6T5R<F]R('=R:71I;F<@(B1T96UP;F%M92(Z("0A73L*8VAM;V0@
M)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA;64H)'1E
M;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E
M='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F
M:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%
M?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\
M/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L
M("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D
M<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@*R`Q
M*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA
M;64L("1S>7-[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\
M)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D
M<')O9VYA;64D<WES>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)'-Y<WM?97AE
M?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D<WES
M>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D
M14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I
M<B`]?B!S+UQ1)'-Y<WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D
M:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](BDL(&QA<W0I"FEF
M("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(["B@H
M)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B*2P@;&%S
M="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B
M(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?
M4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI
M(#P@,"D@>PHD<')O9VYA;64@/2`B+B1S>7-[7V1E;&EM?21P<F]G;F%M92([
M"GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E
M=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'
M971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S
M+UXH/SU<+EPN/UQ1)'-Y<WM?9&5L:6U]7$4I+R1P=V0D<WES>U]D96QI;7TO
M.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?
M:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@
M*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@
M,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@
M4%)/1TY!344@*2`I('L*9&5L971E("1%3E9[(E!!4E\D7R)].PI]"F9O<B`H
M<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLB4$%27R1?
M(GT@/2`D14Y6>R)005)?1TQ/0D%,7R1?(GT@:68@97AI<W1S("1%3E9[(E!!
M4E]'3$]"04Q?)%\B?3L*?0II9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E
M("1%3E9[4$%27T-,14%.?3L*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q
M=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L
M<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E
M($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG
M.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A
M<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`*
M*3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L
M(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE
M('%Q6W!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE
M(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN70IU;FQE<W,@+64@)'!R
M;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]
M?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ
M7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?
M7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)2
M3U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH`````<&5R;'AS:2YC````
M``````$;`SL```#<````&O__@Q@```5P__^%6````/C__X90```!*/__AS``
M``&(__^'P````;C__XDH```!]/__BA@```(P__^,N````G#__XTP```"K/__
MC6@```+`__^.0````OS__XY(```#$/__D'````-,__^0J````WC__Y&X```#
MO/__EY@```/P__^8*```!!S__YA8```$//__F6@```2<__^A$```!/#__Z-8
M```%+/__I&@```6P__^[Z```!?#__[Q8```&%/__O9````90__^^V```!H@`
M````````%``````!>E(``7@.`1L,#Z`!!PX`````%````!S__X18````0@``
M````````````%``````!>E(``7@.`1L,#Z`!````````7````!S__X4@````
MW`!&A@Z'#8@,B0N*"HL)C`B-!XX&CP5&#L`"`I@*S\[-S,O*R<C'Q@Z@`4(+
M7`K/SLW,R\K)R,?&#J`!0@M."L_.S<S+RLG(Q\8.H`%""P``````+````'S_
M_X6@````C@!&B@J+"8P(C0>.!H\%1@[8`P)Z"L_.S<S+R@Z@`4(+````.```
M`*S__X8````!8@!&A@Z'#8@,B0N*"HL)C`B-!XX&CP5&#N`#=`K/SLW,R\K)
MR,?&#J`!0@L`````.````.C__X<L````\`!&APV(#(D+B@J+"8P(C0>.!H\%
M1@[((@*4"L_.S<S+RLG(QPZ@`4(+````````/````23__X?@```"G`!&A@Z'
M#8@,B0N*"HL)C`B-!XX&CP5&#M@"`P%D"L_.S<S+RLG(Q\8.H`%""P``````
M`#@```%D__^*0````'0`7H8.APV(#(D+B@J+"8P(C0>.!H\%3`[(`@)(S\[-
MS,O*R<C'Q@Z@`0```````!````&@__^*?````#@`````````.````;3__XJ@
M````U`!&A@Z'#8@,B0N*"HL)C`B-!XX&CP5&#MA"`K@*S\[-S,O*R<C'Q@Z@
M`4(+````$````?#__XL\````!@`````````X```"!/__BS````(D`$:&#H<-
MB`R)"XH*BPF,"(T'C@:/!48.\","=@K/SLW,R\K)R,?&#J`!0@L````H```"
M0/__C1P````V`$J+"8P(C0>.!H\%1@[``F#/SLW,RPZ@`0```````$````)L
M__^-*````0P`1HD+B@J+"8P(C0>.!H\%1@[((@+&"L_.S<S+RLD.H`%""UP*
MS\[-S,O*R0Z@`48+````````,````K#__XWT```%W`!&B@J+"8P(C0>.!H\%
M1@[0`@,%G`K/SLW,R\H.H`%&"P```````"@```+D__^3H````)``1HL)C`B-
M!XX&CP5&#M`"=@K/SLW,RPZ@`4(+````'````Q#__Y0$````+@!&C@:/!48.
MP`)@S\X.H`$```!<```#,/__E!0```$*`$:&#H<-B`R)"XH*BPF,"(T'C@:/
M!48.X`("6@K/SLW,R\K)R,?&#J`!0@M:"L_.S<S+RLG(Q\8.H`%&"P)V"L_.
MS<S+RLG(Q\8.H`%&"P````!0```#D/__E,0```>D`%2&#H<-B`R)"XH*BPF,
M"(T'C@:/!48.J(4"`P*$"L_.S<S+RLG(Q\8.H`%""P,"P@K/SLW,R\K)R,?&
M#J`!1@L````````X```#Y/__G!@```)$`$:'#8@,B0N*"HL)C`B-!XX&CP52
M#M`"`P&\"L_.S<S+RLG(QPZ@`4(+``````!````$(/__GB0```$0`$:)"XH*
MBPF,"(T'C@:/!48.T`(">@K/SLW,R\K)#J`!0@L";`K/SLW,R\K)#J`!1@L`
M`````#P```1D__]]H````CP`1H8.APV(#(D+B@J+"8P(C0>.!H\%1@[H`@,!
ME`K/SLW,R\K)R,?&#J`!0@L````````\```$I/__GK```!>``$Z&#H<-B`R)
M"XH*BPF,"(T'C@:/!48.T`<#%UP*S\[-S,O*R<C'Q@Z@`4(+````````(```
M!.3__[7P````;`!*C@:/!48.P`("6L_.#J`!````````.```!0C__[8\```!
M.`!,A@Z'#8@,B0N*"HL)C`B-!XX&CP5>#L`"`JX*S\[-S,O*R<C'Q@Z@`4(+
M````-```!43__[<X```!1@!&B`R)"XH*BPF,"(T'C@:/!6P.P`("I@K/SLW,
MR\K)R`Z@`48+```````0```%?/__N$@````,````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````C&````````"+0``````````$````````"Q0``
M```````!`````````M4`````````#````````!C(``````````T```````!;
MN``````````9````````N\@`````````&P`````````(`````````!H`````
M``"[T``````````<``````````@`````;__^]0````````*0``````````4`
M```````,"``````````&`````````V@`````````"@````````0]````````
M``L`````````&``````````5`````````````````````P```````+W8````
M``````(````````%$``````````4``````````<`````````%P```````!.X
M``````````<````````18``````````(`````````E@`````````"0``````
M```8`````````!X`````````"`````!O___[``````@```$`````;____@``
M`````!$``````&____\``````````0````!O___P````````$$8`````;___
M^0`````````.````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````"[V``````````````````````````````9-@```````!E6````````
M&78````````9E@```````!FV````````&=8````````9]@```````!H6````
M````&C8````````:5@```````!IV````````&I8````````:M@```````!K6
M````````&O8````````;%@```````!LV````````&U8````````;=@``````
M`!N6````````&[8````````;U@```````!OV````````'!8````````<-@``
M`````!Q6````````''8````````<E@```````!RV````````'-8````````<
M]@```````!T6````````'38````````=5@```````!UV````````'98`````
M```=M@```````!W6````````'?8````````>%@```````!XV````````'E8`
M```````>=@```````!Z6````````'K8````````>U@```````![V````````
M'Q8````````?-@```````!]6````````'W8````````?E@```````!^V````
M````']8`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````'^@``````````````````,`(_____P````````````!>P@``
M`````%Q$``````````````````!<Y````````%SH````````7K8```````!<
M2@```````%Z^``````````````````!>I@```````%ZL````````````````
M``!>R$=#0SH@*$1E8FEA;B`Q,BXR+C`M-2D@,3(N,BXP```N<VAS=')T86(`
M+FEN=&5R<``N;F]T92YG;G4N8G5I;&0M:60`+FYO=&4N04))+71A9P`N9VYU
M+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I
M;VY?<@`N<F5L82YD>6X`+G)E;&$N<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR
M;V1A=&$`+F5H7V9R86UE7VAD<@`N96A?9G)A;64`+FEN:71?87)R87D`+F9I
M;FE?87)R87D`+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S`"YC;VUM96YT````
M````````````````````````````````````````````````````````````
M```````````````````````````+`````0`````````"`````````C@`````
M```".``````````/`````````````````````0``````````````$P````<`
M`````````@````````)(`````````D@`````````)```````````````````
M``0``````````````"8````'``````````(````````";`````````)L````
M`````"`````````````````````$```````````````T;___]@`````````"
M`````````I`````````"D`````````#8````!0``````````````"```````
M````````/@````L``````````@````````-H`````````V@````````(H```
M``8````"``````````@`````````&````$8````#``````````(````````,
M"`````````P(````````!#T````````````````````!``````````````!.
M;____P`````````"````````$$8````````01@````````"X````!0``````
M`````````@`````````"````6V____X``````````@```````!$`````````
M$0``````````8`````8````!``````````@``````````````&H````$````
M``````(````````18````````!%@`````````E@````%```````````````(
M`````````!@```!T````!`````````!"````````$[@````````3N```````
M``40````!0```!4`````````"``````````8````?@````$`````````!@``
M`````!C(````````&,@`````````0`````````````````````0`````````
M`````'D````!``````````8````````9"````````!D(````````!N``````
M```````````````$`````````"````"$`````0`````````&````````'^@`
M```````?Z````````#O0````````````````````"```````````````B@``
M``$`````````!@```````%NX````````6[@`````````+```````````````
M``````0``````````````)`````!``````````(```````!;Z````````%OH
M````````0.@````````````````````(``````````````"8`````0``````
M```"````````G-````````"<T`````````#<````````````````````!```
M````````````I@````$``````````@```````)VP````````G;`````````%
MP`````````````````````@``````````````+`````.``````````,`````
M``"[R````````*O(``````````@````````````````````(``````````@`
M``"\````#P`````````#````````N]````````"KT``````````(````````
M````````````"``````````(````R`````8``````````P```````+O8````
M````J]@````````"``````8```````````````@`````````$````-$````!
M``````````,```````"]V````````*W8`````````B@`````````````````
M```(``````````@```#6`````0`````````#````````P`````````"P````
M``````"`````````````````````"```````````````W`````@`````````
M`P```````,"`````````L(``````````*`````````````````````@`````
M`````````.$````!`````````#```````````````````+"``````````!X`
M```````````````````!``````````$````!`````P``````````````````
J``````````"PG@````````#J`````````````````````0``````````
